#
# spec file for package pcsc-ccid
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pcsc-ccid
%define _name ccid
Version:        1.6.1
Release:        1.1
Summary:        PCSC Driver for CCID Based Smart Card Readers and GemPC Twin Serial Reader
License:        LGPL-2.1-or-later
Group:          Productivity/Security
URL:            https://ccid.apdu.fr/
Source:         https://ccid.apdu.fr/files/%{_name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Source2:        https://ccid.apdu.fr/files/%{_name}-%{version}.tar.xz.asc
Source3:        %{name}.keyring
BuildRequires:  automake
BuildRequires:  flex
BuildRequires:  libusb-1_0-devel
BuildRequires:  meson
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkgconfig
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(udev)
# openSUSE package pcsc-lite 1.6.6 is the first one which creates the scard UID and GID:
Requires:       pcsc-lite >= 1.6.6
%define ifddir %(pkg-config libpcsclite --variable=usbdropdir)
%define LBRACE (
%define RBRACE )
%define QUOTE "
%define BACKSLASH \\
%define USBDRIVERS %(set -x ; xz -d <%{S:0} | tr a-z A-Z | sed -n 's/^ATTRS{IDVENDOR}==%{QUOTE}%{BACKSLASH}%{LBRACE}[^%{QUOTE}]*%{BACKSLASH}%{RBRACE}%{QUOTE}, ATTRS{IDPRODUCT}==%{QUOTE}%{BACKSLASH}%{LBRACE}[^%{QUOTE}]*%{BACKSLASH}%{RBRACE}%{QUOTE}.*$/modalias%{LBRACE}usb:v%{BACKSLASH}1p%{BACKSLASH}2d*dc*dsc*dp*ic*isc*ip*%{RBRACE}/p' | tr '%{BACKSLASH}n' ' ')
# We are not using Supplements here. User may want to choose between pcsc-lite and openct:
# Generic CCID devices:
Enhances:       modalias(usb:*ic0Bisc00d*dc*dsc*dp*ic*isc*ip*)
# Kobil mIDentity:
Enhances:       modalias(usb:v0D46p4081d*dc*dsc*dp*ic*isc*ip*)
# Other supported devices:
Enhances:       %USBDRIVERS
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains a generic USB CCID (Chip/Smart Card Interface
Devices) driver.

This driver is meant to be used with the PCSC-Lite daemon from the
pcsc-lite package.

%prep
%autosetup -n %{_name}-%{version}
cp -a src/openct/LICENSE LICENSE.openct
cp -a src/towitoko/README README.towitoko

%build
%meson	-Dserial=true \
        -Dzlp=true

%meson_build %{?_smp_mflags}

%install
%meson_install
# Copied elsewhere:
mkdir -p %{buildroot}/%{_udevrulesdir}
sed 's:GROUP="pcscd":GROUP="scard":' <src/92_pcscd_ccid.rules >%{buildroot}/%{_udevrulesdir}/92_pcscd_ccid.rules

%files
%defattr(-,root,root)
# NEWS is empty
%doc AUTHORS README.md contrib/Kobil_mIDentity_switch/README_Kobil_mIDentity_switch.txt SCARDGETATTRIB.md
%license COPYING LICENSE.openct
%config (noreplace) %{_sysconfdir}/reader.conf.d/*
%{ifddir}/*
%{_udevrulesdir}/*.rules

%changelog
* Sat Jan 25 2025 Andrea Manzini <andrea.manzini@suse.com>
- Version 1.6.1
  * fix 'parse' build issues on some systems (pthread & strlcpy)
  * Some other minor improvements
* Wed Jun  5 2024 Axel Braun <axel.braun@gmx.de>
- Version 1.6.0
  - uses meson build system now
  - Add support of
  - Aladdin R.D. JCR SecurBio
  - AvidCard CAC Smart Card Reader
  - FujitsuTechnologySolutions GmbH Dual Smartcard Reader D321
  - Ledger Stax
  - NXP Pegoda 3
  - authenton #1- CTAP2.1
  - provide files for meson build tool (replaces autoconf/automake)
  - Add possibility to set/get NAD on T=1 for MEP
  - multi-slots readers
  - Better handling of reader removal
  - Use CLOCK_MONOTONIC for timeouts
  - Some other minor improvements
* Thu Feb 29 2024 jun wang <jgwang@suse.com>
- Update to version 1.5.5
  * Add support of
  - Alpha-Project ANGARA Token
  - Broadcom Corp 58200 (idProduct: 0x5864)
  - Broadcom Corp 58200 (idProduct: 0x5865)
  - Imprivata USB CCID
  - KAPELSE eS-KAP-Ad
  - Kapelse inSide
  - KAPELSE KAP-Care
  - KAPELSE KAP-eCV
  - KAPELSE KAP-GO
  - KAPELSE KAP-LINK2
  - Kapelse KAP-Move
  - Kapelse Ti-Kap
  - rf IDEAS USB CCID
  - SIMHUB pcsc reader
  * support Kapelse readers on macOS (composite as multislot)
  * Some other minor improvements
* Thu Nov 16 2023 Otto Hollmann <otto.hollmann@suse.com>
- Fix build dependency - require zlib-devel instead of zlib
* Mon Oct 30 2023 Axel Braun <axel.braun@gmx.de>
- version 1.5.4
  * fix a regression introduced in 1.5.3
- version 1.5.3
  * Add support of
  - ACS ACR1552 1S CL Reader
  - ACS ACR1552 CL Reader
  - ACS ACR1581
  - ACS ACR40T ICC Reader
  - ACS ACR40U ICC Reader
  - ACS WalletMate 1S CL Reader
  - Aktiv Rutoken SCR 3101 NFC Reader
  - CIRIGHT ONE PASS U2F
  - Dexon Tecnologias Digitais LTDA eSmartDX
  - Excelsecu Card reader
  - GHI NC001
  - Identiv uTrust Token Flex
  - SpringCard M519 with idProduct: 0x6212
  - SpringCard M519 with idProduct: 0x621A
  - WCMi SD5931
  * parse: create output.bin file
  * udev: Disable USB-persist for CCID devices
  * configure: fail if flex is not found
  * Some other minor improvements
* Thu Feb  2 2023 Ben Greiner <code@bnavigator.de>
- version 1.5.2
  * Add support of
  - KAPELSE KAP-LINK
  - LDU LANDI
  - Sensyl SSC-HV Reader
  - TOKEN2 MFA NFC Reader
  - TOKEN2 Molto2
  - Thales RF Reader
  * Alcor Micro AU9560: Remove high speeds since they are not
    supported
  * Hack for AlcorMicro AU9560 and Acos-ID card
  * configure.ac: disable the use of --disable-usbdropdir
* Tue Nov 15 2022 Axel Braun <axel.braun@gmx.de>
- version 1.5.1
  * Add support of
  - Access IS ATR220 with idProduct: 0x0184
  - Alcor Link AK9567
  - Alcor Link AK9572
  - BLUTRONICS TAURUS NFC
  - CHERRY SmartTerminal ST-1144
  - CREATOR CRT-603(CZ1) CCR
  - Dexon Tecnologias Digitais LTDA DXToken
  - ESMART Reader ER433x ICC
  - ESMART Reader ER773x Dual & 1S
  - Flight system consulting Incredist
  - Ledger Nano S
  - Ledger Nano S Plus
  - Ledger Nano SP
  - Ledger Nano X
  - SafeNet eToken Fusion
  - Sensyl SSC-NFC Reader
  * Adjust USB drivers path at run-time via environment variable PCSCLITE_HP_DROPDIR
  * configure.ac: add --enable-strict option
  * Fix a problem with AUTO PPS readers and ATR convention inverse cards
  * examples/scardcontrol:
  - add support of 6A xx error codes
  - check WinSCard error early
  - parse wLcdLayout & bEntryValidationCondition
  * macOS: log non sensitive strings as "%%{public}s"
  * Some other minor improvements
* Thu Jan 27 2022 Axel Braun <axel.braun@gmx.de>
- verson 1.5.0
  * Add support of
  - ACS ACR1281U
  - Circle CCR7125 ICC
  - Circle CIR125 ICC
  - Circle CIR125-DOT ICC
  - Circle CIR215 CL with iProduct 0x2100
  - Circle CIR315 DI
  - Circle CIR315 with idProduct: 0x0324
  - Circle CIR315 with idProduct: 0x7004
  - Circle CIR415 CL
  - Circle CIR515 ICC
  - Circle CIR615 CL
  - Circle CIR615 CL & 1S
  - ELYCTIS CL reader
  - Nitrokey Nitrokey 3
  - Thales Shield M4 Reader
  * Add support of simultaneous slot access on multi slots readers
  * Use FeliCa instead of Felica on SONY request
  * Fix SafeNet eToken 5110 SC issue
  * Allow vendor control commands for Omnikey 5427 CK
  * always compute readTimeout to use a value greater than default 3 seconds
  * Check the bSeq value when receiving a CCID frame
  * Avoid logging errors when a reader is removed
  * Some other minor improvements
* Mon Aug 30 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.4.36
  * Add support of
  - Lenovo Lenovo Smartcard Wired Keyboard II
  - REINER SCT tanJack USB
  - SafeNet eToken 5110+ FIPS
  - SafeNet eToken 5300 C
  - jSolutions s.r.o. Multi SIM card reader 4/8
  * parse: fix check when bNumDataRatesSupported = 0
* Sun Jul 25 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.4.35
  * Add support of
  - ArkSigner Connect2Sign
  - Circle CCR7115 ICC
  - Circle CCR7315
  - Circle CIR215 CL
  - Circle CIR215 PICC
  - Circle CIR315
  - Circle CIR315 (idProduct: 0x3100)
  - Circle CIR315 CL
  - Circle CIR315 Dual & 1S
  - Circle CIR415 CL & 1S
  - Circle Idaxis SecurePIV
  - DUALi DE-ABCM6 RFRW
  - Feitian R701
  - Generic EMV Smartcard Reader (0x058C:0x9590)
  - INMAX DWR18 HC
  - INMAX DWR18 HPC
  - Identiv Identiv uTrust 4711 F CL + SAM Reader
  - Identiv uTrust 3721 Contactless Reader
  - Infocrypt HWDSSL DEVICE
  - Infocrypt Token++ lite
  - MK Technology KeyPass D1
  - SONY Felica RC-S300/P
  - SONY Felica RC-S300/S
  - SONY Felica RC-S660/U
  - SYNNIX CL-2100R
  - SoloKeys Solo 2
  - Spyrus Inc PocketVault P-3X (idProduct: 0x3203)
  * parse: use "ICCD token" for ICCD tokens
  * Support 4 card slots with Feitian R502 C9
  * ccid_usb: ask for bNumDataRatesSupported data rates
  * Solve a performance issue with T=1 and CCID_CLASS_AUTO_PPS_PROP
  * Fix a possible buffer overflow in T0ProcACK
  * IFDHSetProtocolParameters: set IFSC/IFSD only for TPDU readers
  * CCID serial: Reset buffers on failed read
  * Fix yylex missing symbol
  * Gemalto pinpad: fix incorrect bEntryValidationCondition for
    SecurePINVerify and SecurePINModify
  * Fix bit4id miniLector-EVO pinpad support
  * The Kobil TriBank reader does NOT support extended APDU
* Sun Jan 24 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.4.34
  * Add support for
    ACS ACR1252IMP Reader
    ACS CryptoMate EVO
    Aktiv Rutoken SCR 3001 Reader
    Avtor KP-375BLE
    Avtor SC Reader KP382
    BIT4ID mLector AIR DI V3
    BIT4ID miniLector AIR NFC v3
    Bit4id Digital-DNA Key (ProductID 0x2354)
    Canokeys Canokey
    DESKO GmbH IDenty chrom
    DESKO GmbH PENTA Scanner
    FT Biopass CCID
    FT Biopass FIDO2
    FT Biopass KB CCID
    FT Biopass KB FIDO CCID
    Feitian BLE CCID Dongle
    Feitian R805
    Feitian vR504 Contactless Reader
    GoTrust Idem Key
    Identiv uTrust 3720 Contactless Reader
    Sunrex HP USB Business Slim Smartcard CCID Keyboard
    sysmocom - s.f.m.c. GmbH sysmoOCTSIM
  * Fail if the requested protocol is not supported by reader
  * Disable USB suspend for the AlcorMicro AU9520 reader
  * Return "no smart card" if we get notified during a transmit
  * Minor improvements reported by Maksim Ivanov
  * Some other minor improvements
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Rely on _udevrulesdir as provided by the distros.
* Sat Jun 27 2020 Wolfgang Rosenauer <wr@rosenauer.org>
- Version 1.4.33
  * added support for
    Genesys Logic CCID Card Reader (idProduct: 0x0771)
    Swissbit Secure USB PU-50n SE/PE
    TOPPAN FORMS CO.,LTD TC63CUT021
  * Update PCSC submodule to get Unicode support
  * Some minor improvements
* Sun May 24 2020 Axel Braun <axel.braun@gmx.de>
- Version 1.4.32
  * Various bugfixes
  * added support for
    CHERRY SECURE BOARD 1.0
    SPECINFOSYSTEMS DIAMOND HSM
    SPECINFOSYSTEMS DIAMOND PLUS token
    SPECINFOSYSTEMS DIAMOND PRO token
    Access IS ATR210
    Access IS ATR220
    Sysking MII136C
    Add support of min & max PIN size for the Cherry KC 1000 SC
    Ledger Nano X support
    SpringCard Puck
    Gemalto RF CR5400
    Purism, SPC Librem Key
    SpringCard SpringCore (idProduct: 0x601A)
    SpringCard E518 (idProduct: 0x611A)
    SpringCard H518 (idProduct: 0x612A)
    SpringCard Puck (dProduct: 0x613A)
    SpringCard SpringCore (idProduct: 0x6012)
    SpringCard E518 (idProduct: 0x6112)
    SpringCard H518 (idProduct: 0x6122)
    AF Care One (idProduct: 0xAFC0)
    AF Care One (idProduct: 0xAFC1)
    AF Care Two (idProduct: 0xAFC2)
    AF Care Two (idProduct: 0xAFC3)
    Doctolib SR
    F-Secure Foundry USB Armory Mk II
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
* Sun Aug 11 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- Updated to version 1.4.31
  * Add support of
    ACS ACR1252 Reader
    Aladdin R.D. JaCartaReader
    Alcor Link AK9563
    AvestUA AvestKey
    Avtor SecureToken (idProduct: 0x0020)
    Bit4id TokenME EVO v2
    Bit4id miniLector AIR EVO
    Bit4id miniLector Blue
    Broadcom Corp 58200 (idProduct: 0x5843)
    Broadcom Corp 58200 (idProduct: 0x5844)
    Broadcom Corp 58200 (idProduct: 0x5845)
    Certgate GmbH ONEKEY ID 2 USB
    HID Global Crescendo Key 0x0028
    HID Global Crescendo Key 0x0029
    HID Global Crescendo Key 0x002B
    HID Global Crescendo Key 0x002D
    Identiv SCR3500 C Contact Reader
    InfoCert WirelessKey
    NXP PN7462AU CCID
    Route1 MobiKEY Fusion3
    SPECINFOSYSTEMS DIAMOND token
  * Some minor improvements for debug
* Tue Jan 29 2019 sbrabec@suse.com
- Update URL.
* Sat Sep 22 2018 wr@rosenauer.org
- Updated to version 1.4.30
  * The project moved to https://ccid.apdu.fr/
  * Add support of
    ACS ACR33 ICC Reader
    BIFIT ANGARA
    Broadcom Corp 58200
    Certgate GmbH AirID 2 USB
    DC.Ltd DC4 5CCID READER
    Genesys Logic CCID Card Reader
    Genesys Logic Combo Card Reader
    InfoThink IT-500U Reader
    Spyrus Inc WorkSafe Pro (ProductID 0x3117)
  * Disabled readers
    REINER SCT cyberJack RFID standard
  * Update reader names for
    Fujitsu Keyboard KB100 SCR
    Fujitsu Keyboard KB100 SCR eSIG
    FujitsuTechnologySolutions GmbH Keyboard KB SCR2
    Yubico YubiKey CCID
    Yubico YubiKey FIDO+CCID
    Yubico YubiKey OTP+CCID
    Yubico YubiKey OTP+FIDO+CCID
  * Fix libusb config descriptor leak
  * Fix leaking an allocated bundle in case no matching reader was found
* Sun Feb 25 2018 wr@rosenauer.org
- Updated to version 1.4.29
  * Add support of
    Access IS NFC Smart Module (With idProduct 0x0164)
    Bit4id Digital-DNA Key
    Bit4id Digital-DNA Key BT
    Bluink Ltd. Bluink CCID
    Chicony HP Skylab USB Smartcard Keyboard
    HID Global OMNIKEY 5023 Smart Card Reader
    HID Global OMNIKEY 5027CK CCID CONFIG IF
    KeyXentic Inc. KX906 Smart Card Reader
    Spyrus Inc Rosetta USB
    Spyrus Inc WorkSafe Pro
    Watchdata USB Key (idProduct: 0x0418)
  * The C3PO LTC31 v2 wrongly declares PIN support
  * Remove extra EGT patch because it has bad side effects
* Sun Oct 15 2017 wr@rosenauer.org
- Updated to version 1.4.28
  * Add support of
    Athena IDProtect Flash
    Elatec TWN4/B1.06/CPF3.05/S1SC1.32/P (Beta 3)
    HID Global OMNIKEY 5122 Dual
    HID Global OMNIKEY 5122 Smartcard Reader
    IIT E.Key Crystal-1
    KRONEGGER Micro Core Platform
    KRONEGGER NFC blue Reader Platform
    Ledger Nano S
    REINER SCT cyberJack RFID standard
    REINER SCT cyberJack one
    SAFETRUST SABRE SCR
    SafeNet eToken 5300
    Unicept GmbH AirID USB Dongle
    Watchdata USB Key
    mCore SCard-Reader
  * Disabled readers
    Jinmuyu Electronics Co., Ltd. MR800
  * Fix non-pinpad HID global devices
  * udev rules
    allow rule overwrite
    disable USB autosuspend on C3PO LTC31 v1 reader
  * some minor improvements
* Mon May 22 2017 wr@rosenauer.org
- Updated to version 1.4.27
  * Add support of
    ACS ACR1255U-J1
    ACS CryptoMate (T2)
    ANCUD CCID USB Reader & RNG
    DUALi DE-620 Combi
    FT CCID
    FT CCID KB
    FT U2F CCID KB
    FT U2F CCID KBOARD
    HID Global OMNIKEY 5422 Smartcard Reader
    InfoThink IT-102MU Reader
    Kapsch TrafficCom USB SAM reader
    MK Technology KeyPass S1
    Mulann PVT
    Regula RFID Reader
    Spyrus Inc PocketVault P-3X
    Unicept GmbH AirID USB
  * Add Microchip SEC1210 UART support (when connected on a serial port)
  * Add Zero Length Packet (ZLP) support for Gemalto IDBridge CT30 and K30
    enable the patch using ./configure --enable-zlp
  * Add support of HID Omnikey 5422 as multi slot reader (for macOS)
  * Escape command: signals buffer overflow instead of silently
    truncating the buffer
  * Fix a bug with multi readers and pcscd uses hotplug_libusb
    (not the recommended configuration)
  * Some minor improvements
* Sat Jan  7 2017 wr@rosenauer.org
- Updated to version 1.4.26
  * Add support of
    Bit4id Digital DNA Key
    Bit4id tokenME FIPS v3
    INGENICO Leo
    appidkey GmbH ID60-USB
  * PowerOn: the default algorithm is now 5V then 1.8V then 3V then fail.
    It is still possible to change the initial voltage in the
    Info.plist file.
    Now, in any case, all the values are tried before failing.
  * Negotiate maximum baud rate when bNumDataRatesSupported = 0
  * Some minor improvements
* Mon Oct  3 2016 wr@rosenauer.org
- Updated to version 1.4.25
  * Add support of
    Aladdin R.D. JaCarta (idProduct: 0x0402)
    Broadcom Corp 5880 (idProduct: 0x5832)
    Broadcom Corp 5880 (idProduct: 0x5833)
    Broadcom Corp 5880 (idProduct: 0x5834)
    ESMART Token GOST X2 ET1020-A
    Feitian VR504 VHBR Contactless & Contact Card Reader
    Feitian bR500
    Gemalto K50
    appidkey GmbH ID100-USB  SC Reader
    appidkey GmbH ID50 -USB
  * Remove suport of
    Broadcom Corp 5880 (idProduct: 0x5800)
    Broadcom Corp 5880 (idProduct: 0x5805)
    KEBTechnology KONA USB SmartCard
  * Fix crash with GemCore Pos Pro and GemCore Sim Pro
  * Some minor improvements
* Mon May 30 2016 wr@rosenauer.org
- Updated to version 1.4.24
  * Add support of
    Generic USB Smart Card Reader
    Giesecke & Devrient GmbH StarSign CUT S
    HID AVIATOR Generic
  * better support of Elatec TWN4 SmartCard NFC
  * better support of SCM SCL011
  * fix SCARD_ATTR_VENDOR_IFD_SERIAL_NO attribute size
  * fix a race condition on card events with multiple readers
  * Some minor improvements
* Thu Apr 21 2016 wr@rosenauer.org
- Updated to version 1.4.23
  * Add support of
    ACS ACR3901U ICC Reader
    Alcor Micro AU9560
    Cherry SmartTerminal XX44
    HID Global OMNIKEY 3x21 Smart Card Reader
    HID Global OMNIKEY 5022 Smart Card Reader
    HID Global OMNIKEY 6121 Smart Card Reader
    IonIDe Smartcard Reader reader
    KACST HSID Reader
    KACST HSID Reader Dual Storage
    KACST HSID Reader Single Storage
  * Remove support of
    VMware Virtual USB CCID
  * Fix a busy loop consuming 100%% of CPU for some composite USB devices
    impacted readers: Yubico Yubikey NEO U2F+CCID and Broadcom BCM5880
  * Remove support of (unused) option DRIVER_OPTION_RESET_ON_CLOSE
  * log libusb error name instead of decimal value
  * Some minor improvements
* Sun Jan 10 2016 wr@rosenauer.org
- Updated to version 1.4.22
  * Add support of
    Aktiv Rutoken PINPad 2
    Aladdin R.D. JC-WebPass (JC600)
    Aladdin R.D. JCR-770
    Aladdin R.D. JaCarta
    Aladdin R.D. JaCarta Flash
    Aladdin R.D. JaCarta LT
    Aladdin R.D. JaCarta U2F (JC602)
    Athena ASEDrive IIIe Combo Bio PIV
    Athena ASEDrive IIIe KB Bio PIV
    GEMALTO CT1100
    GEMALTO K1100
    Hitachi, Ltd. Hitachi Biometric Reader
    Hitachi, Ltd. Hitachi Portable Biometric Reader
    Nitrokey Nitrokey Storage
    THURSBY SOFTWARE TSS-PK1
    Thursby Software Systems, Inc. TSS-PK7
    Thursby Software Systems, Inc. TSS-PK8
  * Patch for Microchip SEC1110 reader on Mac OS X (card events notification)
  * Patch for Cherry KC 1000 SC (problem was with a T=1 card and case 2 APDU)
  * Fix support of FEATURE_MCT_READER_DIRECT for the Kobil mIDentity visual reader
  * Set timeout to 90 sec for PPDU (Pseudo APDU) commands. This
    change allows the use of a Secure Verify command sent as a PPDU
    through SCardTransmit().
  * Fix a crash when reader reader initialization failed
  * Fix initialization bug with Gemalto Pinpad reader on Mac OS X
  * Some minor bugs fixed
* Sun Oct 25 2015 wr@rosenauer.org
- Updated to version 1.4.21
  * Add support of
    ACS ACR1252 Dual Reader
    Chicony HP USB Smartcard CCID Keyboard JP
    Chicony HP USB Smartcard CCID Keyboard KR
    FT ePass2003Auto
    Feitian bR301 BLE
    Feitian iR301 (ProductID 0x0619)
    Feitian iR301 (ProductID 0x061C)
    Identiv @MAXX ID-1 Smart Card Reader
    Identiv @MAXX Light2 token
    Identiv CLOUD 2980 F Smart Card Reader
    Identiv Identiv uTrust 4701 F Dual Interface Reader
    Identiv SCR3500 A Contact Reader
    Identiv SCR3500 B Contact Reader
    Identiv SCR35xx USB Smart Card Reader
    Identiv uTrust 2900 R Smart Card Reader
    Identiv uTrust 2910 R Smart Card Reader
    Identiv uTrust 2910 R Taglio SC Reader
    Identiv uTrust 3512 SAM slot Token
    Identiv uTrust 3522 embd SE RFID Token
    Identiv uTrust 3700 F CL Reader
    Identiv uTrust 3701 F CL Reader
    Identive Identive CLOUD 4000 F DTC
    Liteon HP SC Keyboard - Apollo (Liteon)
    Liteon HP SC Keyboard - Apollo JP (Liteon)
    Liteon HP SC Keyboard - Apollo KR (Liteon)
    Nitrokey Nitrokey HSM
    Nitrokey Nitrokey Pro
    Nitrokey Nitrokey Start
    Rocketek RT-SCR1
    VASCO DIGIPASS 875
    WatchCNPC USB CCID Key
  * Remove support of
    Crypto Stick Crypto Stick v1.4 is an old version of Nitrokey Nitrokey Pro
    Free Software Initiative of Japan Gnuk Token is an old version
    of Nitrokey Nitrokey Start
  * Add Feitain R502 dual interface (composite) reader on Mac OS X
  * display a human readable version of the error code returned by libusb
  * Mac OS X: wait until libusb/the reader is ready
  * some minor bugs fixed
* Wed Aug  5 2015 wr@rosenauer.org
- Updated to version 1.4.20
  * Add support of
    ACS ACR1251 Dual Reader
    Access IS NFC Smart Module
    BIFIT iToken
    BLUTRONICS BLUDRIVE II CCID (idProduct: 0x1079)
    Generic MultiCard Device
    NXP Pegoda 2 N
    SafeNet eToken 5100
    SafeNet eToken 7300
    Yubico Yubikey 4 CCID
    Yubico Yubikey 4 OTP+CCID
    Yubico Yubikey 4 OTP+U2F+CCID
    Yubico Yubikey 4 U2F+CCID
  * Depends on libusb version 1.0.9 instead of 1.0.8
  * The O2 Micro Oz776 reader only supports 9600 bps
- spec file cleanup
- remove pgp validation from build (now handled via OBS)
* Wed May 13 2015 wr@rosenauer.org
- Updated to version 1.4.19
  * Add support of
    AK910 CKey (idProduct 0x0001)
    AK910 CKey (idProduct 0x0011)
    AK910 IDONE
    Broadcom Corp 5880 (idProduct: 0x5804)
    CASTLES EZCCID Smart Card Reader
    Cherry KC 1000 SC
    Cherry KC 1000 SC Z
    Cherry KC 1000 SC/DI
    Cherry KC 1000 SC/DI Z
    Cherry TC 1300
    Chicony USB Smart Card Keyboard
    Elatec TWN4 SmartCard NFC
    Feitian 502-CL
    Feitian eJAVA Token
    FujitsuTechnologySolutions GmbH Keyboard KB100 SCR
    FujitsuTechnologySolutions GmbH Keyboard KB100 SCR eSIG
    Hewlett-Packard HP lt4112 Gobi 4G Module
    Identive SCT3522CC token
    OMNIKEY AG 6121 USB mobile
    PIVKey T800
    REINER SCT tanJack Bluetooth
    Watchdata USB Key
  * Remove ZLP patch for Gemalto IDBridge CT30 and K30. The patch was
    causing problems with the K50.  A new reader firmware (version F)
    solved the problem so the patch is no more needed.
  * Fix a memory leak in an error path
  * some minor bugs removed
* Sat Sep 13 2014 wr@rosenauer.org
- Updated to version 1.4.18
  * Add support of
    Cherry Cherry TC 1100
    Cherry Smart Card Reader USB
    Cherry Smartcard Keyboard G87-1xx44
    FujitsuTechnologySolutions GmbH Keyboard KB SCR2
    Lenovo Lenovo USB Smartcard Keyboard
    Yubico Yubikey NEO OTP+U2F+CCID
    Yubico Yubikey NEO U2F+CCID
    eID_R6 001 X8
  * fix support of Omnikey CardMan 3121
  * reduce memory consumed when configured with --enable-embedded
  * prepare the port to UEFI
* Thu Jun 12 2014 wr@rosenauer.org
- Updated to version 1.4.17
  * Add support of
    Feitian R502
    Free Software Initiative of Japan Gnuk Token
    German Privacy Foundation Crypto Stick v2.0
    HID Global veriCLASS Reader
    HID OMNIKEY 5025-CL
    Identive Technologies Multi-ISO HF Reader - USB
    OMNIKEY 5421
    OMNIKEY AG 3121 USB
    udea MILKO V1.
  * Fix support of O2 Micro Oz776. The reader is limited to 9600 bps
  * some minor bugs removed
* Sun Mar 23 2014 wr@rosenauer.org
- Updated to version 1.4.16
  * Add support of
    Crypto Stick Crypto Stick v1.4
    Hewlett Packard USB Smartcard CCID Keyboard
    IID AT90S064 CCID READER
    INSIDE Secure VaultIC 405 Smart Object
    INSIDE Secure VaultIC 441 Smart Object
    Microchip SEC1110
    Microchip SEC1210
    Watchdata W5181
  * Add support of DRIVER_OPTION_DISABLE_PIN_RETRIES
    The Gemalto pinpad reader sends a VERIFY command with no PIN value
    in order to retreive the remaining retries from the card. Some
    cards (like the OpenPGP card) do not support this.
    It is now possible to disable this behavior from the Gemalto Pinpad
    and Covadis Véga Alpha.
  * Add support of WTX received before SW during Secure Pin Entry Verify
    The Swiss health care card sends a WTX request before returning
    the SW code. If the reader is in TPDU and the card is in T=1 the
    driver must manage the request itself.
- added alternative key (E8F9C57E) to keyring
* Sat Feb 15 2014 wr@rosenauer.org
- Updated to version 1.4.15
  * Add support of
    DUALi DRAGON NFC READER
    Feitian bR301
    Gemalto CR30 reader in serial communication
    Gemalto Ezio Shield Pro SC
    IIT E.Key Almaz-1C
  * PIN_MODIFY_STRUCTURE & PIN_VERIFY_STRUCTURE: Fix calculation of
    the command length after pcsc-lite 1.8.9 (October 2013) changed
    the PCSC/reader.h header
  * Add specific PIN min (0) & max (25) sizes for SmartTerminal ST-2xxx
  * Do not get the data rates if bNumDataRatesSupported = 0
  * Support Gemalto features for pinpad readers MinimumPINSize,
    MaximumPINSize and bEntryValidationCondition are fetched from the
    reader firmware
  * disable (broken) pinpad for Fujitsu SmartCase KB SCR eSIG
  * some minor bugs removed
* Tue Nov 26 2013 wr@rosenauer.org
- Updated to version 1.4.14
  * Add support of
    Gemalto GemCore SIM Pro firmware 2.0 (using USB)
  * report FEATURE_IFD_PIN_PROPERTIES only for pinpad readers
  * Generalize the management of (old) readers with bDeviceClass = 0xFF
  * some minor bugs removed
* Thu Oct 10 2013 wr@rosenauer.org
- Updated to version 1.4.13
  * Add support of
    Access IS ePassport Reader
    Planeta RC700-NFC CCID
  * Add support of Windows value for CM_IOCTL_GET_FEATURE_REQUEST
    Windows uses 0x313520 for SCARD_CTL_CODE(3400)
    pcsc-lite uses 0x42000D48 for SCARD_CTL_CODE(3400)
    RDP aplications (like rdesktop) will convert SCardControl()
    commands from a Windows application (so using 0x313520) to pcsc-lite.
  * fix multi-slot support for card movement notification
  * some minor bugs removed
* Tue Aug 13 2013 wr@rosenauer.org
- Updated to version 1.4.12
  * Add support of
    HID OMNIKEY 5127 CK
    HID OMNIKEY 5326 DFR
    HID OMNIKEY 5427 CK
    Ingenico WITEO USB Smart Card Reader (Base and Badge)
    SecuTech SecuTech Token
  * Add support of card movement notifications for multi-slot readers
  * Check libusb is at least at version 1.0.8
  * Get the serialconfdir value from pcsc-lite pkg config instead of
    using $(DESTDIR)/$(sysconfdir)/reader.conf.d/ if not specified
    (pcsc-lite does not provide that information yet so the value
    is set manually
  * some minor bugs removed
* Wed Jun 12 2013 wr@rosenauer.org
- Updated to version 1.4.11
  * Add support of
    Gemalto IDBridge CT30
    Gemalto IDBridge K30
    SCM Microsystems Inc. SCL010 Contactless Reader
    SCM Microsystems Inc. SDI011 Contactless Reader
    THRC reader
  * Better management of time extension requests
  * parse: better support of devices with bInterfaceClass = 0xFF
  * udev rule file: Remove setting group to pcscd, remove support
    of Linux kernel < 2.6.35 for auto power up management
  * some minor bugs removed
* Sun Apr 21 2013 wr@rosenauer.org
- Updated to version 1.4.10
  * Add support of
    ACS APG8201 USB Reader with PID 0x8202
    GIS Ltd SmartMouse USB
    Gemalto IDBridge K3000
    Identive CLOUD 2700 F Smart Card Reader
    Identive CLOUD 2700 R Smart Card Reader
    Identive CLOUD 4500 F Dual Interface Reader
    Identive CLOUD 4510 F Contactless + SAM Reader
    Identive CLOUD 4700 F Dual Interface Reader
    Identive CLOUD 4710 F Contactless + SAM Reader
    Inside Secure AT90SCR050
    Inside Secure AT90SCR100
    Inside Secure AT90SCR200
    SCR3310-NTTCom USB SmartCard Reader
    SafeTech SafeTouch
    SpringCard H512 Series
    SpringCard H663 Series
    SpringCard NFC'Roll
    Yubico Yubikey NEO CCID
    Yubico Yubikey NEO OTP+CCID
  * Add support of time extension for Escape commands
* Wed Jan 16 2013 wr@rosenauer.org
- Updated to version 1.4.9
  * Add support of
    Aktiv Rutoken PINPad In
    Aktiv Rutoken PINPad Ex
    REINER SCT cyberJack go
  * Info.plist: Correctly handle reader names containing &
* Wed Jan  9 2013 sbrabec@suse.cz
- Verify GPG signature.
* Thu Oct 18 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Mon Oct  8 2012 wr@rosenauer.org
- Updated to version 1.4.8:
  * Add support of
    SCR3310-NTTCom USB (was removed in version 1.4.6)
    Inside Secure VaultIC 420 Smart Object
    Inside Secure VaultIC 440 Smart Object
  * Wait up to 3 seconds for reader start up
  * Add support of new PC/SC V2 part 10 properties:
    dwMaxAPDUDataSize
    wIdVendor
    wIdProduct
  * Use helper functions from libPCSCv2part10 to parse the
    PC/SC v2 part 10 features
* Tue Jun 26 2012 wr@rosenauer.org
- Updated to version 1.4.7:
  * Add support of
    ACS ACR101 ICC Reader
    ACS CryptoMate64
    Alcor Micro AU9522
    Bit4id CKey4
    Bit4id cryptokey
    Bit4id iAM
    Bit4id miniLector
    Bit4id miniLector-s
    CCB eSafeLD
    Gemalto Ezio Shield Branch
    KOBIL Systems IDToken
    NXP PR533
  * KOBIL Systems IDToken special cases:
    Give more time (3 seconds instead of 2) to the reader to answer
    Hack for the Kobil IDToken and Geman eID card. The German eID
    card is bogus and need to be powered off before a power on
    Add Reader-Info-Commands special APDU/command
  - Manufacturer command
  - Product name command
  - Firmware version command
  - Driver version command
  * Use auto suspend for CCID devices only (Closes Alioth bug
    [#313445] "Do not activate USB suspend for composite devices:
    keyboard")
  * Fix some error management in the T=1 TPDU state machine
  * some minor bugs removed
  * some minor improvements added
- do not call bootstrap since autoconf requirement is bleeding edge
  and only works on Factory/12.2 - also seems to be unnecessary
* Sun Apr 15 2012 wr@rosenauer.org
- Updated to version 1.4.6:
  * Add support of Avtor SC Reader 371, Avtor SecureToken,
    DIGIPASS KEY 202, Fujitsu SmartCase KB SCR eSIG,
    Giesecke & Devrient StarSign CUT,
    Inside Secure VaultIC 460 Smart Object,
    Macally NFC CCID eNetPad reader, OmniKey 6321 USB,
    SCM SDI 011, Teridian TSC12xxF, Vasco DIGIPASS KEY 101
  * Remove support of readers without a USB CCID descriptor file
    0x08E6:0x34C1:Gemalto Ezio Shield Secure Channel
    0x08E6:0x34C4:Gemalto Ezio Generic
    0x04E6:0x511A:SCM SCR 3310 NTTCom
    0x0783:0x0008:C3PO LTC32 USBv2 with keyboard support
    0x0783:0x9002:C3PO TLTC2USB
    0x047B:0x020B:Silitek SK-3105
  * Disable SPE for HP USB CCID Smartcard Keyboard. The reader is
    bogus and unsafe.
  * Fix a problem with ICCD type A devices. We now wait for device
    ready
  * Secure PIN Verify and PIN Modify: set the minimum timeout to
    90 seconds
  * Add support of wIdVendor and wIdProduct properties
  * Add support of dwMaxAPDUDataSize
  * Add support of Gemalto firmware features
  * some minor bugs removed
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Oct 17 2011 wr@rosenauer.org
- Updated to version 1.4.5:
  * Add support of Alcor Micro AU9540, Ubisys 13.56MHz RFID (CCID),
    BIFIT USB-Token iBank2key, BIFIT iBank2Key, Gemalto Ezio Shield
    PinPad reader, Gemalto SA .NET Dual, Precise Sense MC reader
    (with fingerprint), SDS DOMINO-Key TWIN Pro
  * Add support of bPPDUSupport and FEATURE_CCID_ESC_COMMAND
  * SCARD_ATTR_VENDOR_NAME and SCARD_ATTR_VENDOR_IFD_VERSION are
    not the vendor name and version of the driver but of the IFD:
    InterFace Device i.e. the smart card reader.  We then return the
    USB iManufacturer string as SCARD_ATTR_VENDOR_NAME and USB
    bcdDevice as SCARD_ATTR_VENDOR_IFD_VERSION
  * reduce binary size by removing unused features from simclist
  * Fix some warnings reported by Coverity
* Wed May 18 2011 wr@rosenauer.org
- Updated to version 1.4.4:
  * Add support of Gemalto Ezio Shield, Gemalto Ezio CB+, Gemalto Ezio
    Shield Secure Channel, Gemalto Ezio Shield PinPad and Gemalto Ezio
    Generic
  * Activate USB automatic power suspend. The Linux kernel should
    power off the reader automatically if it is not used (pcscd is not
    running).
  * Add support of TLV Properties wLcdMaxCharacters and wLcdMaxLines
  * Add support of Neowave Weneo, Vasco DIGIPASS 920, SCM SCL011,
    Feitian ePass2003 readers
  * use :libudev: instead of :libhal: naming scheme
  * Do not install RSA_SecurID_getpasswd and Kobil_mIDentity_switch
    and the associated documentation.
  * the Secure Pin Entry of the HP USB Smart Card Keyboard is bogus
    so disable it
  * Add support of Feitian SCR310 reader (also known as 301v2), ACS
    APG8201 PINhandy 1, Oberthur ID-ONE TOKEN SLIM v2, new Neowave
    Weneo token, Vasco DIGIPASS KEY 860, Vasco DIGIPASS KEY 200,
    Xiring Leo v2, Xiring MyLeo, Aktiv Rutoken lite readers
  * Add back support of "bogus" Oz776, REINER SCT and BLUDRIVE II
  * disable use of interrupt card events for multi slots readers
* Wed Feb 16 2011 oneukum@suse.de
- Added support for internal reader in HP laptops
* Wed Jan  5 2011 sbrabec@suse.cz
- Updated to version 1.4.1:
  * Security fix (bnc#661000, CVE-2010-4530).
  * Migrated to libusb-1_0.
  * udev support.
  * Compatible with pcsc-lite-1.6.
  * See ChangeLog for details.
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 1.3.11:
  * Incompatible change: Remove support of Reiner-SCT cyberJack
    pinpad(a) on request of Reiner-SCT. Use pcsc-cyberjack instead.
  * Should work: Panasonic USB Smart Card Reader 7A-Smart, ATMEL
    AT91SC192192CT-USB, Alcor Micro SCR001, Aktiv Rutoken ECP,
    Synnix STD200, more Neowave Weneo tokens, Feitian SCR301
    Raritan D2CIM-DVUSB VM/CCID
  * New known firmware: Kobil EMV CAP, ACS ACR122U-WB-R with bogus
    firmware < 2.06
  * Broadcom 5880 should work a bit better
  * Fixes for GemProx DU/SU and hacks for other Gemalto readers
  * SCM SCL010 Contactless Reader is not supported
  * Add support of FEATURE_MCT_READERDIRECT. Now only on the Kobil
    TriB@nk reader.
  * Support --disable-class argument to build a NON class driver.
  * HAL support fixes.
  * Add support of PIN_PROPERTIES_STRUCTURE structure and
    FEATURE_IFD_PIN_PROPERTIES
  * It is possible to configure composite devices to be seen as
    multi-slots.
  * Other fixes, improvement and updates.
* Tue Apr  7 2009 sbrabec@suse.cz
- Updated to version 1.3.10:
  * Added a hack to support the bogus OpenGPG card.
  * Should work: Precise Biometrics 200 MC, Precise Biometrics 250
    MC, SafeNet IKey4000 used in different device, Atmel
    AT98SC032CT, Neowave Weneo, MSI StarReader SMART, VMware Virtual
    USB CCID reader, ACS ACR122U PICC Interface, HP MFP Smart Card
    Reader, KONA USB SmartCard, SpringCard CrazyWriter, CSB6 Basic,
    CSB6 Secure, CSB6 Ultimate, EasyFinger Standard, EasyFinger
    Ultimate and Prox'N'Roll, Atmel AT91SO, Cherry SmartTerminal
    ST-1200USB, Aladdin eToken PRO USB 72K Java.
  * Differentiate between KOBIL mIDentity M and XL.
  * Known readers: SpringCard Prox'N'Roll, CSB6 Basic, EasyFinger
    Ultimate, CSB6 Ultimate, EasyFinger Standard, CrazyWriter, CSB6
    Secure, Pro-Active CSB6 Ultimate is renamed SpringCard CSB6
    Ultimate
  * Unsupported: Broadcom 5880, jNet Technology jToken s1.
  * Disabled support of the contcatless part of SDI010 and SCR331DI.
  * Avoid a "Duplicate frame detected" error.
  * Use a very long timeout for PowerUp since the card can be very
    slow to send the full ATR (up to 30 seconds at 4 MHz)
  * Driver will work in a multi-reader configuration.
- Use modalias supplements instead of eID issuer locales.
- Require pcsc-lite.
- Removed custom hotplug support. Now integrated in pcsc-lite.
* Mon Jan 26 2009 ro@suse.de
- added udev diretories to filelist to fix build
* Tue Jan  6 2009 sbrabec@suse.cz
- Do not call autoreconf for SLE10.
* Fri Nov 14 2008 sbrabec@suse.cz
- On request of author reverted to libusb0 to prevent errors.
  http://www.nabble.com/Re%%3A-patch-for-libusb-0.9.3-libusb-os-linux_usbfs.c-p20421276.html
* Fri Sep  5 2008 sbrabec@suse.cz
- Updated to version 1.3.8:
  * Fixes and code improvements.
  * New readers that should work: Should work: Pro-Active CSB6
    Ultimate, id3 Semiconductors CL1356A HID, Vasco DP905,
    KEBTechnology KONA USB SmartCard, Precise Biometrics 250 MC,
    Covadis.ch Alya and Vega-Alpha.
* Wed Apr  2 2008 sbrabec@suse.cz
- Updated to version 1.3.5:
  * new supported devices
  * documentation improves
  * code changes
  * for more see ChangeLog
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 1.3.0:
  * code changes
  * crash fixes
  * firmware updates
  * new command line tools
* Thu May 31 2007 sbrabec@suse.cz
- Build requires libusb-devel.
* Tue Feb 13 2007 sbrabec@suse.cz
- Updated to version 1.2.1:
  * Support for non CCID generic readers.
  * Supported O2Micro Oz7762.
  * Support for SCARD_ATTR_VENDOR_IFD_VERSION,
  * SCARD_ATTR_VENDOR_NAME and SCARD_ATTR_MAXINPUT tags used by
    SCardGetAttrib(). Read SCARDGETATTRIB.txt for more.
  * Support for OmniKey CardMan 5125, CardMan 1021, C3PO LTC32, Teo
    by Xiring, HP USB Smartcard Reader.
  * Support Extended APDU (up to 64KB) for readers in TPDU mode
    or Extended APDU mode. This only works for T=1 cards.
  * Support for C3PO LTC31 (new version), OmniKey CardMan 3021, HP
    USB Smart Card Keyboard, Actividentity (ActiveCard) Activkey
    Sim, id3 Semiconductors CL1356D and CL1356T, Alcor Micro AU9520
  * Support the contactless interface of the SCR331-DI-NTTCOM
  * Increased the USB timeout used for PIN verify/modify.
  * Endian fixes.
  * Other fixes.
* Fri Nov 24 2006 mjancar@suse.cz
- set IFSC in the SetParameters when required (#223566)
* Fri Aug 11 2006 stark@suse.de
- update to version 1.0.1
  * add support for Axalto Reflex USB v3, SCM Micro SDI 010, Winbond
    Electronics W81E381 chipset, Gemplus GemPC Card, Athena ASE IIIe
    KB USB, OmniKey CardMan 3621
  * improve support of Cherry XX44 keyboard for PIN verify and change
    (circumvent firmware bugs)
  * do not use LTPBundleFindValueWithKey() from pcscd since this
    function has been removed from pcscd API
  * use -fvisibility=hidden is available to limit the number of
    exported symbols
* Sat Apr  1 2006 sndirsch@suse.de
- added missing locale provides (Bug #161867)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 mjancar@suse.cz
- move to separate source package
* Mon Jan  2 2006 stark@suse.de
- removed obsolete hotplug stuff for cyberjack
- Updated pcsc-lite to version 1.2.9-beta9
- Updated CCID driver to 0.9.4
- Updated GemPC driver to 1.0.0
- package pkgconfig files to be able to build drivers outside
  the package
* Tue Dec 20 2005 ro@suse.de
- removed unpackaged man-page symlinks
* Tue Nov 29 2005 ro@suse.de
- remove keeper from nfb (unused)
* Mon Oct 10 2005 stark@suse.de
- Updated towitoko driver to 2.0.7 and install USB bundle
* Wed Sep 21 2005 stark@suse.de
- Repackaged CCID as bundle for USB usage (#116497)
* Tue Sep 20 2005 stark@suse.de
- handle old reader.conf in upgrade case
- compile with -fno-strict-aliasing
- fixed missing return in ctapi-cyberjack
* Sat Sep 17 2005 stark@suse.de
- Updated pcsc-lite to version 1.2.9beta8 (#116497)
  * use /etc/reader.conf.d/
  * adapted init script to create /etc/reader.conf
- Updated cyberjack driver to version 2.0.9
  * use rpath for cyberjack tools
- Updated ccid driver to version 0.9.3 (#116497)
- Use RPM_OPT_FLAGS everywhere
- Fixed serious compiler warnings
* Mon Sep  5 2005 skh@suse.de
- fix off-by-one error in hotplug_libusb.c [#112964]
* Mon Aug 29 2005 skh@suse.de
- Remove unnecessary files from pcsc-acr38 again [#112927]
* Mon Aug 29 2005 skh@suse.de
- package ACR38 driver in correct bundle format [#112927]
- remove orphaned /var/run/pcscd.pub when necessary [#112928]
- update ACR38u driver to version 100705 to fix crash when reader
  is plugged in [#112964]
* Tue Aug 16 2005 skh@suse.de
- Updated ACR38u driver to version 100703
* Tue Jul 26 2005 okir@suse.de
- Added ACR38u driver
* Tue Jul 26 2005 okir@suse.de
- Updated description in init script (#79287)
* Thu Jun 16 2005 meissner@suse.de
- use RPM_OPT_FLAGS in 1 more driver
- added includes to avoid implict declaration of memcpy and similar.
* Mon Apr 18 2005 ro@suse.de
- make it build with gcc-4
* Thu Mar 17 2005 okir@suse.de
- Disable support for extended-apdus, it eats 32MB of memory (#73629)
* Thu Mar 10 2005 okir@suse.de
- Fix default search location for USB bundles
* Fri Jan 21 2005 okir@suse.de
- Updated to latest upstream version
- Updated several drivers
- Added CCID driver
- Provide a more informative readers.conf file (#42620)
* Thu Jan 20 2005 ro@suse.de
- drop subpackage gpr400
* Wed Apr 28 2004 ro@suse.de
- compile formaticc with no-strict-aliasing
- fix unused return type in musclecard.c
* Wed Mar 31 2004 okir@suse.de
- Properly install testpcsc, formaticc (#37625)
- Build towitoko driver with --enable-win32-com
* Thu Mar 18 2004 okir@suse.de
- cyberjack apps installed in /bin should be executable (#36409)
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Aug  5 2003 mge@suse.de
- merge ctapi-cyberjack into pcsc-lite: two additional
  packages are created: ctapi-cyberjack and pcsc-cyberjack
* Wed Jun 25 2003 ro@suse.de
- remove unpackaged files from buildroot
- added directories to filelist
* Fri Nov 29 2002 okir@suse.de
- added -fPIC when building eToken driver
* Fri Nov 29 2002 okir@suse.de
- Updated to latest upstream version
- Included driver for Aladdin eToken PRO
- More GNU auto#*@! headaches
- Various minor fixes
* Wed Aug 28 2002 okir@suse.de
- Moved shared objects to /usr/lib64 on ppc64/s390x (#18421)
* Mon Aug  5 2002 olh@suse.de
- fix initscript, Should-start: setserial hotplug
* Fri Aug  2 2002 okir@suse.de
- added PreReq for insserv_and_fillup
* Wed Jul 31 2002 okir@suse.de
- fixed build problem on s390x (force aclocal.m4 regen)
* Tue Jun 25 2002 ro@suse.de
- use -fPIC when building a shared lib
* Wed Jun 12 2002 okir@suse.de
- fix for bug #15051 (hey, it's a palindrome bug:):
  missing %%doc DRIVERS file; misc silly binaries moved
  out of /usr/bin
* Tue Apr 30 2002 okir@suse.de
- Fixed build problem introduced by previous patch
* Tue Apr 30 2002 okir@suse.de
- updated to latest upstream version
- added drivers for these readers: Towitoko, Schlumberger Reflex 6x,
  Gemplus GPR 400, GemPlus GemPC 410/430
* Mon Apr  8 2002 ro@suse.de
- fixed for latest automake/autoconf
* Wed Feb 13 2002 stark@suse.de
- spec-file cleanup
- LSB compliant init-script
* Mon Jan 14 2002 ro@suse.de
- removed START_PCSCD
* Wed Nov 14 2001 ro@suse.de
- call aclocal
* Sun Aug 26 2001 mge@suse.de
- updated to 1.0.0Beta
- fixed /etc/init.d/pcscd status-handling (bug #9069)
* Thu Jun  7 2001 ro@suse.de
- fix broken Makefile.am
* Sun Apr 22 2001 mge@suse.de
- update to 0.9.1
* Wed Apr 18 2001 mge@suse.de
- created package
